@@ -797,15 +797,17 @@ class FieldUnmarshallerMixin:
             cached_value = self._unmarshalled_field_cache.get(
                 field_name, MISSING)
         if cached_value is not MISSING:
-            return cached_value
+            return cached_value[0]
 
         field = field.bind(self.context)
         marshaller = getMultiAdapter((field, self.request), IFieldMarshaller)
         try:
             if IUnmarshallingDoesntNeedValue.providedBy(marshaller):
                 value = None
+                flag = IUnmarshallingDoesntNeedValue
             else:
                 value = getattr(self.entry, field.__name__)
+                flag = None
             if detail is NORMAL_DETAIL:
                 repr_value = marshaller.unmarshall(self.entry, value)
             elif detail is CLOSEUP_DETAIL:
@@ -820,11 +822,14 @@ class FieldUnmarshallerMixin:
             # access to the resource altogether, use our special
             # 'redacted' tag: URI for the field's value.
             repr_value = self.REDACTED_VALUE
+            value = None
+            flag = Unauthorized
 
         unmarshalled = (marshaller.representation_name, repr_value)
 
         if detail is NORMAL_DETAIL:
-            self._unmarshalled_field_cache[field_name] = unmarshalled
+            self._unmarshalled_field_cache[field_name] = (
+                unmarshalled, (field, value, flag))
         return unmarshalled
 
     def _field_with_html_renderer(self, field_name, field):
@@ -1215,14 +1220,16 @@ class EntryManipulatingResource(ReadWriteResource):
             # The changeset contained new values for some of this object's
             # fields, and the notification event may have changed others.
             # Clear out any fields that changed.
-            for name, ignored in self._unmarshalled_field_cache.items():
+            for name, cached in self._unmarshalled_field_cache.items():
+                cached, (field, old_value, flag) = cached
+                if flag is IUnmarshallingDoesntNeedValue:
+                    continue
                 force_clear = False
                 try:
-                    old_value = getattr(entry_before_modification, name, None)
-                    new_value = getattr(self.entry.context, name, None)
+                    new_value = getattr(self.entry, field.__name__)
                 except Unauthorized:
-                    # Clear the cache, just to be safe.
-                    force_clear = True
+                    if flag is not Unauthorized:
+                        force_clear = True
                 if force_clear or new_value != old_value:
                     del(self._unmarshalled_field_cache[name])
 
